@@ -56,30 +56,26 @@ rbind_body_groupi <- function(x) {
 
 
 build_tt <- function(x, output = NULL) {
-  output <- sanitize_output(output)
+  x <- sanitize_output(x, output)
+  output <- infer_output(x)
 
   x <- switch(output,
-    html = swap_class(x, "tinytable_bootstrap"),
-    bootstrap = swap_class(x, "tinytable_bootstrap"),
+    html = {
+      if (identical(x@html_engine, "tabulator")) {
+        swap_class(x, "tinytable_tabulator")
+      } else {
+        swap_class(x, "tinytable_html")
+      }
+    },
     latex = swap_class(x, "tinytable_tabularray"),
     markdown = swap_class(x, "tinytable_grid"),
-    gfm = swap_class(x, "tinytable_grid"),
     typst = swap_class(x, "tinytable_typst"),
     dataframe = swap_class(x, "tinytable_dataframe"),
-    tabulator = swap_class(x, "tinytable_tabulator"),
+    stop("Unsupported output format: '", output, "'. Supported formats are: html, latex, markdown, typst, dataframe", call. = FALSE)
   )
 
   x@output <- output
 
-  # pre-process: theme_*() calls that need formatting conditional on @output
-  for (p in x@lazy_prepare) {
-    o <- attr(p, "output")
-    if (is.null(o) || x@output %in% o) {
-      x <- p(x)
-    }
-  }
-
-  x <- render_fansi(x)
 
   # Calculate which positions are body vs group
   if (nrow(x@group_data_i) == 0) {
@@ -94,13 +90,45 @@ build_tt <- function(x, output = NULL) {
     x <- eval(l)
   }
 
-  # apply styling AFTER formatting/escaping to avoid escaping the style brackets
-  x <- style_notes(x)
-  x <- style_caption(x)
+  # apply lazy subset operations before inserting group rows
+  x <- subset_lazy(x)
 
   # insert group rows into body
   x <- rbind_body_groupi(x)
 
+  # apply theme_*() before style_tt()
+  lazy_style <- x@lazy_style
+  x@lazy_style <- list()
+
+  # pre-process: theme_*() calls that need formatting conditional on @output
+  # this is useful after rbind() because we now have the final indices and headers
+  for (p in x@lazy_prepare) {
+    o <- attr(p, "output")
+    if (is.null(o) || x@output %in% o) {
+      x <- p(x)
+    }
+  }
+
+  # apply theme_*() before style_tt()
+  x@lazy_style <- c(x@lazy_style, lazy_style)
+
+  for (p in x@lazy_style) {
+    p[["x"]] <- x
+    x <- eval(p)
+  }
+
+  # Fix colspan that exceeds column count after lazy styles are evaluated
+  if (nrow(x@style) > 0) {
+    end <- x@style$j + x@style$colspan - 1
+    x@style$colspan <- ifelse(
+      !is.na(end) & end > x@ncol,
+      x@style$colspan - (end - x@ncol),
+      x@style$colspan)
+  }
+
+  # apply styling AFTER formatting/escaping to avoid escaping the style brackets
+  x <- style_notes(x)
+  x <- style_caption(x)
 
   # plots and images
   for (l in x@lazy_plot) {
@@ -111,21 +139,6 @@ build_tt <- function(x, output = NULL) {
   # add footnote markers just after formatting, otherwise appending converts to string
   x <- footnote_markers(x)
 
-  # data frame we trim strings, pre-padded for markdown
-  if (x@output == "dataframe") {
-    tmp <- x@data_body
-    for (i in seq_along(tmp)) {
-      tmp[[i]] <- trimws(tmp[[i]])
-    }
-    x@data_body <- tmp
-  }
-
-  # markdown styles are applied manually after formatting to have consistent decimals
-  # but before drawing the table becuase we need to act on individual cells
-  if (x@output %in% c("markdown", "gfm", "dataframe")) {
-    x <- style_eval(x)
-  }
-
   # draw the table
   x <- build_eval(x)
 
@@ -138,12 +151,10 @@ build_tt <- function(x, output = NULL) {
     x <- group_eval_j(x, j = seq_len(ncol(x)), ihead = ihead)
   }
 
-  # markdown styles are applied earlier
-  if (!x@output %in% c("markdown", "gfm", "dataframe")) {
-    x <- style_eval(x)
-  } else {
-    x <- grid_colspan(x)
-  }
+  x <- style_eval(x)
+
+  # no-op: only modifies markdown
+  x <- grid_colspan(x)
 
   x <- finalize(x)
 
@@ -156,7 +167,7 @@ build_tt <- function(x, output = NULL) {
   }
 
   x@table_string <- lines_drop_consecutive_empty(x@table_string)
-  if (output == "gfm") {
+  if (x@markdown_style == "gfm") {
     assert_dependency("pandoc")
     x@table_string <- paste(
       pandoc::pandoc_convert(text = x@table_string, to = "gfm"),
