@@ -76,8 +76,8 @@ expect_snapshot_print(tab, label = "markdown-footnote")
 if (!is_local) {
   exit_file("Run on Vincent's machine")
 }
-options(tinytable_print_output = "gfm")
-expect_snapshot_print(tt(head(iris)), label = "markdown-gfm")
+options(tinytable_print_output = "markdown")
+expect_snapshot_print(tt(head(iris)) |> theme_markdown(style = "gfm"), label = "markdown-gfm")
 
 # Long group labels - row groups
 options(tinytable_print_output = "markdown")
@@ -133,6 +133,39 @@ tab <- tt(x) |>
   style_tt(4, 2, colspan = 2)
 expect_snapshot_print(tab, label = "markdown-colspan_multiple")
 
+# Test theme_empty() followed by theme_markdown() - should restore grid lines
+options(tinytable_print_output = "markdown")
+tab <- tt(head(iris)[1:3, 1:3]) |>
+  theme_empty() |>
+  theme_markdown(vline = TRUE, hline = TRUE)
+expect_snapshot_print(tab, label = "markdown-theme_empty_restore_grid")
+
+# Test theme_empty() alone - should have no grid lines
+tab <- tt(head(iris)[1:3, 1:3]) |>
+  theme_empty()
+expect_snapshot_print(tab, label = "markdown-theme_empty_no_grid")
+
+# Test theme_markdown grid options - hline only
+tab <- tt(head(iris)[1:3, 1:3]) |>
+  theme_markdown(hline = TRUE, vline = FALSE)
+expect_snapshot_print(tab, label = "markdown-hline_only")
+
+# Test theme_markdown grid options - vline only
+tab <- tt(head(iris)[1:3, 1:3]) |>
+  theme_markdown(hline = FALSE, vline = TRUE)
+expect_snapshot_print(tab, label = "markdown-vline_only")
+
+# Test theme_markdown with header line disabled
+tab <- tt(head(iris)[1:3, 1:3]) |>
+  theme_markdown(hline_header = FALSE)
+expect_snapshot_print(tab, label = "markdown-no_header_line")
+
+# Test theme_empty() then selective restoration
+tab <- tt(head(iris)[1:3, 1:3]) |>
+  theme_empty() |>
+  theme_markdown(hline = TRUE, vline = FALSE)
+expect_snapshot_print(tab, label = "markdown-theme_empty_hline_only")
+
 # restore
 options(tinytable_print_output = NULL)
 
